@@ -23,6 +23,7 @@ try:
         Task, Parallel, Map, Pass, Wait, Choice, Succeed, Fail,
         Retry, Catch,
     )
+    from .magic import LambdaTask
     from .choice_rule import (
         ChoiceRule,
         and_, or_, not_,
@@ -32,5 +33,5 @@ try:
     from .actions import task_context
     from .state_machine import StateMachine
     from .constant import Constant
-except ImportError as e:
+except ImportError as e:  # pragma: no cover
     print(e)
